import "core-js/modules/es.array.includes";
import React from 'react';
import renderer from 'react-test-renderer';
import Checkbox, { CheckboxGroupContext, CheckboxGroup } from '../Checkbox';
import checkboxConstants, { CheckboxGroupConstant } from '../Checkbox.constantProps';
describe('Checkbox component', () => {
  it('should render the Checkbox', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      value: "primary",
      size: checkboxConstants.size.medium
    }));
    const testInstance = ele.toJSON();
    expect(testInstance).toMatchSnapshot();
  });
  it('should render the Checkbox with text=PrimaryCheck', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      value: "primary",
      size: checkboxConstants.size.medium,
      text: "PrimaryCheck"
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.text).toBe('PrimaryCheck');
  });
  it('should render the Checkbox with variant=outlined', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      value: "primary",
      size: checkboxConstants.size.medium,
      text: "PrimaryCheck"
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.variant).toBe('outlined');
  });
  it('should render the Checkbox with variant=contained', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      value: "primary",
      size: checkboxConstants.size.medium,
      text: "PrimaryCheck"
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.variant).toBe('outlined');
  });
  it('should render the Checkbox with variant=filled', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      value: "primary",
      size: checkboxConstants.size.medium,
      text: "PrimaryCheck"
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.variant).toBe('outlined');
  });
  it('should render the Checkbox with value=Primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.value).toBe('primary');
  });
  it('should render the Checkbox with name=Primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.name).toBe('Primary');
  });
  it('should render the Checkbox with checked', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      checked: true
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.checked).toBe(true);
  });
  it('should render the Checkbox with checked', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      checked: false
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.checked).toBe(false);
  });
  it('should render the Checkbox with indeterminate', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      indeterminate: true
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.indeterminate).toBe(true);
  });
  it('should render the Checkbox with indeterminate', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      indeterminate: false
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.indeterminate).toBe(false);
  });
  it('should render the Checkbox with size=small', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.small
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.size).toBe('size_sm');
  });
  it('should render the Checkbox with size=medium', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.size).toBe('size_md');
  });
  it('should render the Checkbox with size=large', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.large
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.size).toBe('size_lg');
  });
  it('should render the Checkbox with color=primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.color).toBe('primary');
  });
  it('should render the Checkbox with color=danger', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.danger
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.color).toBe('danger');
  });
  it('should render the Checkbox with color=success', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.large,
      color: checkboxConstants.color.success
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.color).toBe('success');
  });
  it('should render the Checkbox with id=check_1', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      id: 'check_1'
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.id).toBe('check_1');
  });
  it('should render the Checkbox with disabled', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      disabled: true
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.disabled).toBe(true);
  });
  it('should render the Checkbox with isReadOnly', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      isReadOnly: true
    }));
    const testInstance = ele.root;
    expect(testInstance.findByType(Checkbox).props.isReadOnly).toBe(true);
  });
  it('should render the Checkbox with customClassName', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Checkbox, {
      name: "Primary",
      variant: checkboxConstants.variant.outlined,
      text: "PrimaryCheck",
      value: "primary",
      size: checkboxConstants.size.medium,
      customClassName: {
        size: 'xsmall'
      }
    }));
    console.log(ele.toJSON().props.children[0].props.className.split(' ').includes('xsmall'), 'log'); //console.log(testInstance,'ele',ele.toJSON().props.className.split(' ').includes('xsmall'));// className.);
    //expect(ele.toJSON().props.className.split(' ').includes('xsmall')).toBe(true);
  });
  it('should render the Checkboxgroup with direction=row', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
  });
  it('should render the Checkboxgroup with direction=row,gap=xsmall', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.xSmall
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_xs');
  });
  it('should render the Checkboxgroup with direction=row,gap=small', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.small
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_sm');
  });
  it('should render the Checkboxgroup with direction=row,gap=medium', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.medium
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_md');
  });
  it('should render the Checkboxgroup with direction=row,gap=large', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.large
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_lg');
  });
  it('should render the Checkboxgroup with direction=row,gap=none', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.none
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_none');
  });
  it('should render the Checkboxgroup with direction=column', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
  });
  it('should render the Checkboxgroup with direction=column,gap=xsmall', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      gap: CheckboxGroupConstant.gap.xSmall
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_xs');
  });
  it('should render the Checkboxgroup with direction=column,gap=small', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      gap: CheckboxGroupConstant.gap.small
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_sm');
  });
  it('should render the Checkboxgroup with direction=column,gap=medium', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      gap: CheckboxGroupConstant.gap.medium
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_md');
  });
  it('should render the Checkboxgroup with direction=column,gap=large', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      gap: CheckboxGroupConstant.gap.large
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_lg');
  });
  it('should render the Checkboxgroup with direction=column,gap=none', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      gap: CheckboxGroupConstant.gap.none
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_col');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_none');
  });
  it('should render the Checkboxgroup with defaultvalue', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      defaultValue: ['primarych1']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.defaultValue[0]).toBe('primarych1');
    expect(testInstance.findByType(CheckboxGroup).props.defaultValue.length).toBe(1);
    expect(testInstance.findByType(CheckboxGroup).props.children[0].props.value).toBe('primarych1'); //expect(testInstance.findByType(CheckboxGroup).props.children[0].state.isChecked).toBe('primarych1');
  }); // it("should render the Checkboxgroup with selectedvalue",()=>{
  //     let ele= renderer.create(
  //         <CheckboxGroup name='Primarygroup' direction={CheckboxGroupConstant.direction.column} selectedValue={['primarych1']}>
  //             <Checkbox text='PrimaryCheck' value='primarych1' size={checkboxConstants.size.medium}  color={checkboxConstants.color.primary} />
  //             <Checkbox text='PrimaryCheck' value='primarych2' size={checkboxConstants.size.medium}  color={checkboxConstants.color.primary} />
  //             <Checkbox text='PrimaryCheck' value='primarych3' size={checkboxConstants.size.medium}  color={checkboxConstants.color.primary} />
  //         </CheckboxGroup>
  //     )
  //     const testInstance = ele.root;
  //     expect(testInstance.findByType(CheckboxGroup).props.selectedValue).toBe(['primarych1']);
  // });

  it('should render the Checkboxgroup with defaultvalue', () => {
    let mockFunction = jest.fn();
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.column,
      defaultValue: ['primarych1'],
      onChange: mockFunction
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    testInstance.props.onChange();
    expect(mockFunction).toHaveBeenCalled(); //expect(testInstance.findByType(CheckboxGroup).props.children[0].state.isChecked).toBe('primarych1');
  });
  it('should render the Checkboxgroup with direction=row,gap=medium,wrap=wrap', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.medium,
      wrap: CheckboxGroupConstant.wrap.wrap
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_md');
    expect(testInstance.findByType(CheckboxGroup).props.wrap).toBe('wrap');
  });
  it('should render the Checkboxgroup with direction=row,gap=medium,wrap=wrapreverse', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroup, {
      name: "Primarygroup",
      direction: CheckboxGroupConstant.direction.row,
      gap: CheckboxGroupConstant.gap.medium,
      wrap: CheckboxGroupConstant.wrap.wrapReverse
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroup).props.direction).toBe('dir_row');
    expect(testInstance.findByType(CheckboxGroup).props.gap).toBe('spacing_md');
    expect(testInstance.findByType(CheckboxGroup).props.wrap).toBe('wrap_reverse');
  });
  it('should render the Checkboxcontext with defaultvalue', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroupContext, {
      name: "Primarygroup",
      defaultValue: ['primarych1']
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    })));
    const testInstance = ele.root;
    expect(testInstance.findByType(CheckboxGroupContext).props.defaultValue[0]).toBe('primarych1');
    expect(testInstance.findByType(CheckboxGroupContext).props.defaultValue.length).toBe(1);
    expect(testInstance.findByType(CheckboxGroupContext).props.children[0].props.value).toBe('primarych1');
  });
  it('should render the Checkboxcontext with defaultvalue', () => {
    let mockFunction = jest.fn();
    let ele = renderer.create( /*#__PURE__*/React.createElement(CheckboxGroupContext, {
      name: "Primarygroup",
      defaultValue: ['primarych1'],
      onChange: mockFunction
    }, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych1",
      text: "PrimaryCheck",
      value: "primarych1",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych2",
      text: "PrimaryCheck",
      value: "primarych2",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Checkbox, {
      name: "primarych3",
      text: "PrimaryCheck",
      value: "primarych3",
      size: checkboxConstants.size.medium,
      color: checkboxConstants.color.primary
    }))));
    const testInstance = ele.root;
    testInstance.props.onChange();
    expect(mockFunction).toHaveBeenCalled();
  });
});