import React from "react";
import Popup, { PopupContent, PopupTarget } from "../Popup";
import renderer from "react-test-renderer";
import positionMapping from "../Popup.constantProps";

function CustomTarget(props) {
  let {
    togglePopup,
    getTargetRef
  } = props;
  return /*#__PURE__*/React.createElement("div", {
    ref: getTargetRef,
    onClick: togglePopup,
    style: {
      padding: "10px",
      border: "1px dashed pink",
      color: "pink"
    }
  }, "Click Me");
}

function PopupTree(props) {
  let {
    togglePopup,
    getTargetRef
  } = props;
  return /*#__PURE__*/React.createElement(Popup, {
    popupGroup: "tree"
  }, /*#__PURE__*/React.createElement(PopupTarget, {
    text: "Click",
    isRemoveClose: true
  }), /*#__PURE__*/React.createElement(PopupContent, {
    color: positionMapping.color.danger
  })); // return null;
}

describe("Popup component", () => {
  it("should default", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "small"
    }), /*#__PURE__*/React.createElement(PopupContent, null)));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  }); // Sizes

  it("should size as small", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "small",
      color: positionMapping.color.primary
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.small
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as medium", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "medium",
      color: positionMapping.color.primary
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.medium
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as large", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "large",
      color: positionMapping.color.primary
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.large
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as xlarge", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "xlarge",
      color: positionMapping.color.primary
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.xlarge
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  }); // colors

  it("should size as xlarge", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "primary"
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: "default",
      color: positionMapping.color.primary
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as success", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "success"
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: "default",
      color: positionMapping.color.success
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as secondary", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "secondary"
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.default,
      color: positionMapping.color.secondary
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as danger", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, {
      text: "danger"
    }), /*#__PURE__*/React.createElement(PopupContent, {
      size: positionMapping.size.default,
      color: positionMapping.color.danger
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  {
    Object.keys(positionMapping.placement).forEach(val => {
      it(`should placement as ${val}`, () => {
        let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, {
          placement: val
        }, /*#__PURE__*/React.createElement(PopupTarget, {
          text: val,
          variant: "outlined",
          color: positionMapping.color.success
        }), /*#__PURE__*/React.createElement(PopupContent, null)));
        let tree = ele.toJSON();
        expect(tree).toMatchSnapshot();
      });
    });
  }
  it("should tree view ", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, null, /*#__PURE__*/React.createElement(CustomTarget, null)), /*#__PURE__*/React.createElement(PopupContent, {
      color: positionMapping.color.danger
    }, /*#__PURE__*/React.createElement(PopupTree, null))));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should custom target ", () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Popup, null, /*#__PURE__*/React.createElement(PopupTarget, null, /*#__PURE__*/React.createElement(CustomTarget, null)), /*#__PURE__*/React.createElement(PopupContent, {
      color: positionMapping.color.danger
    })));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});