import React from 'react';
import Textarea, { TextareaControlled } from '../Textarea';
import renderer from 'react-test-renderer';
import TextareaConstantProps from '../Textarea.constantProps';
describe('Textarea component', () => {
  it('should display textarea basic component - uncontrolled', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display textarea basic component - controlled', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(TextareaControlled, {
      maxLength: "100",
      placeHolder: "Text Area"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display variants - default', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Textarea, {
      placeHolder: "Text Area",
      variant: TextareaConstantProps.variant.default
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display variants - primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Textarea, {
      placeHolder: "Text Area",
      variant: TextareaConstantProps.variant.primary
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display variants - danger', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Textarea, {
      placeHolder: "Text Area",
      variant: TextareaConstantProps.variant.danger
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display size small', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(TextareaControlled, {
      placeHolder: "Text Area",
      size: TextareaConstantProps.size.small
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display size medium', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(TextareaControlled, {
      placeHolder: "Text Area",
      size: TextareaConstantProps.size.medium
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display size large', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(TextareaControlled, {
      maxLength: "100",
      placeHolder: "Text Area",
      size: TextareaConstantProps.size.large
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display size large - primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should text propertly entered', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary",
      text: "Text Area Working"
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextareaComp').value.contains('Text Area Working')).toBe(true);
  });
  it('should placeHolder propertly entered', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary",
      text: "Text Area Working"
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextareaComp').getAttribute('placeholder')).toMatch(/Text Area/);
  });
  it('Check border applied', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary",
      text: "Text Area Working",
      needBorder: true
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextareaComp').className).toMatch(/needBorder/);
  });
  it('Check border removed', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary",
      text: "Text Area Working",
      needBorder: false
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextareaComp').className).toMatch(/noBorder/);
  });
  it('Check check onchange works', () => {
    let mockfn = jest.fn();
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Textarea, {
      maxLength: "100",
      placeHolder: "Text Area",
      resize: "vertical",
      size: "large",
      variant: "primary",
      text: "Text Area Working",
      needBorder: false,
      onChange: mockfn
    }));
    let onChangeEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextareaComp');
    TestUtils.Simulate.change(onChangeEle);
    expect(mockfn.mock.calls.length).toBe(1);
  });
});