import React from 'react';
import imgUrl from '../../../images/accessibility.png';
import Button from '@zohodesk/base/es/Button/Button';
import Box from '../../layout/Box';
import TextBox from '../../textbox/TextBox';
import style from './AccessibilityControl.module.css';
import { FocusLoop } from './AccessibilityControl__Model.docs';

export default ({ mode, theme }, components) => {
  return {
    header: {
      title: 'AccessibilityControl Component',
      imgUrl: imgUrl,
      description:
        'All the children inside the whole App will be present here. This component is used to KeyBoard Accessibility'
    },
    tabsList: ['defaultFocuscss', 'customfocuscss', 'customAttriute'],
    tabsDetail: {
      defaultFocuscss: {
        displayName: 'Default Focus CSS',
        description:
          'When focusing on an element when using this AccessibilityControl component a css will be loaded on it by default',
        componentsList: ['defaultFocuscss'],
        componentsDetail: {
          defaultFocuscss: {
            // eslint-disable-next-line react/display-name
            customStyle: { focuscss: style.bgColorGreen },
            bindEvent: 'div',
            // eslint-disable-next-line react/display-name
            children: () => {
              return (
                <Box>
                  <TextBox placeholder='TextBox-1' />
                  <br />
                  <br />
                  <TextBox placeholder='TextBox-2' />
                  <br />
                  <br />
                  <TextBox placeholder='TextBox-3' />
                  <br />
                  <br />
                  <Button variant={Button.constantProps.variant.outlined}>cancel</Button> <Button>submit</Button>
                </Box>
              );
            }
          }
        }
      },
      customfocuscss: {
        displayName: 'Custom Focus CSS',
        description:
          "This attribute 'data-aria-focusstyle' should be used to change the css when focusing on an element",
        componentsList: ['customfocuscss'],
        componentsDetail: {
          customfocuscss: {
            // eslint-disable-next-line react/display-name
            customStyle: { focuscss: style.bgColorGreen },
            bindEvent: 'div',
            // eslint-disable-next-line react/display-name
            children: () => {
              return (
                <Box>
                  <div>
                    <TextBox placeholder='TextBox-1' focusClass={style.customKbF} />
                  </div>
                  <br />
                  <div>
                    <TextBox placeholder='TextBox-2' focusClass={style.customKbF} />
                  </div>
                  <br />
                  <div>
                    <TextBox placeholder='TextBox-3' focusClass={style.customKbF} />
                  </div>
                  <br />
                  <span style={{ marginRight: '20px' }}>
                    <Button variant={Button.constantProps.variant.outlined}>cancel</Button>
                  </span>
                  <span style={{ marginRight: '20px' }}>
                    <Button>submit</Button>
                  </span>
                </Box>
              );
            }
          }
        }
      },
      customAttriute: {
        displayName: "Custom Attribute's",
        description: `This All attribute's is used to KeyBoard accessibility`,
        componentsList: ['customAttriute'],

        componentsDetail: {
          customAttriute: {
            customStyle: { focuscss: style.bgColorGreen },
            bindEvent: 'div',
            // eslint-disable-next-line react/display-name
            children: () => {
              return (
                <ol>
                  <li>data-aria-shortcut = click:enter-space</li>
                  <li>data-aria-focusstyle = css className</li>
                  <li>data-accessibility-root = focuscss-props className </li>
                  <li>data-focus-added - current focus element added in attributed</li>
                </ol>
              );
            }
          }
        }
      }
    }
  };
};
