import React from 'react';
import BreadCrumbs from '../BreadCrumbs';
import BreadCrumbItem from '../BreadCrumbItem';
import {create} from "react-test-renderer";
import renderer from 'react-test-renderer';
import {act} from "react-dom/test-utils"
import constantProps from "../../layout/Box.constantProps";
import { render, unmountComponentAtNode } from "react-dom";


let container = null;
beforeEach(() => {
  // setup a DOM element as a render target
  container = document.createElement("div");
  document.body.appendChild(container);
});

afterEach(() => {
  // cleanup on exiting
  unmountComponentAtNode(container);
  container.remove();
  container = null;
});

let list=[
	{text:'text1',url:document.location.href},
	{text:'text2',url:document.location.href},
	{text:'text3',url:document.location.href},
	{text:'text4',url:document.location.href},
	{text:'text5',url:document.location.href},
	{text:'text6',url:document.location.href},
	{text:'text7',url:document.location.href}
]

describe("BreadCrumb component", () => {

	it("should render BreadCrumbs as isFrontSeperator,seperator=/", () => {
		let ele = renderer.create(
			<BreadCrumbs
				items={list}
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'/'}
				active={list.length-1}
				isFrontSeperator={true}
			/>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as isFrontSeperator,seperator=+", () => {
		let ele = renderer.create(
			<BreadCrumbs
				items={list}
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'+'}
				active={list.length-1}
				isFrontSeperator={true}
			/>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as seperator=/", () => {
		let ele = renderer.create(
			<BreadCrumbs
				items={list}
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'/'}
				active={list.length-1}
				isFrontSeperator={false}
			/>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as seperator=+", () => {
		let ele = renderer.create(
			<BreadCrumbs
				items={list}
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'+'}
				active={list.length-1}
				isFrontSeperator={false}
			/>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as isFrontSeperator,seperator=/,children", () => {
		let ele = renderer.create(
			<BreadCrumbs
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'/'}
				active={list.length-1}
				isFrontSeperator={true}
			>
				{
					list.map((listitem,i)=>(
						<BreadCrumbItem key={i} >
							{listitem.text}
						</BreadCrumbItem>
					))
				}
			</BreadCrumbs>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as isFrontSeperator,seperator=+,children", () => {
		let ele = renderer.create(
			<BreadCrumbs
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'+'}
				active={list.length-1}
				isFrontSeperator={true}
			>
				{
					list.map((listitem,i)=>(
						<BreadCrumbItem key={i} >
							{listitem.text}
						</BreadCrumbItem>
					))
				}
			</BreadCrumbs>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as seperator=/,children", () => {
		let ele = renderer.create(
			<BreadCrumbs
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'/'}
				active={list.length-1}
				isFrontSeperator={false}
			>
				{
					list.map((listitem,i)=>(
						<BreadCrumbItem key={i} >
							{listitem.text}
						</BreadCrumbItem>
					))
				}
			</BreadCrumbs>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as seperator=+,children", () => {
		let ele = renderer.create(
			<BreadCrumbs
				align={constantProps.align.vertical}
				direction={constantProps.direction.row}
				wrap={constantProps.wrap.wrap}
				seperator={'+'}
				active={list.length-1}
				isFrontSeperator={false}
			>
				{
					list.map((listitem,i)=>(
						<BreadCrumbItem key={i} >
							{listitem.text}
						</BreadCrumbItem>
					))
				}
			</BreadCrumbs>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});

	it("should render BreadCrumbs as seperator=+,children", () => {
		let ele = renderer.create(
			<BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
			>
				{
					list.map((listitem,i)=>(
						<BreadCrumbItem 
							key={i} 
							href={listitem.url} 
							text={listitem.text+listitem.text+listitem.text+listitem.text+listitem.text+listitem.text} />
					))
				}
			</BreadCrumbs>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
	it("should render BreadCrumbs as seperator=+,children,collapse=true,maxItems=2", () => {
		let ele = renderer.create(
			<BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
				items={list}
				collapse={true}
				maxItems={2}
			/>
		);
		let tree = ele.toJSON();
		expect(tree).toMatchSnapshot();
	});
// 	it("test the onClick props", () => {
// 		const mockFunction = jest.fn();
// 		const mf2=(args)=>{console.log(args); return mockFunction(...args)}
// 		let wrapper = create(
// 			<BreadCrumbs
// 				seperator={'+'}
// 				customId={'custom'}
// 				active={list.length-1}
// 				isFrontSeperator={true}
// 				items={list}
// 				onSelect={mockFunction}
// 			/>
// 		);
// //		const p = wrapper.root.findByProps("custom0");
// 		//wrapper.root.findAllByType("a").props.onClick();
// 		let allElem=wrapper.root.findAllByType('a');
// 		ReactTestUtils.Simulate.click();
// 		//console.log('wrap',allElem[0],'wrapw',Object.keys(wrapper));
// 		// let abc=findRenderedDOMComponentWithTag(
// 		// 	wrapper.getInstance(),
// 		// 	"a"
// 		// )
// 		// console.log(wrapper.root.findAllByProps('customId'));
// 		// allElem[0].props.onClick()
// 		console.log(mockFunction.mock.calls.length,'mock')
// //		expect(mockFunction).toBeCalledWith("custom0_link");
// 	});

	it("children count", () => {
		let rootIns = create(
			<BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
				items={list}
			/>
		).root;
		expect(rootIns.findAllByType("a").length).toEqual(list.length-1);
	});
	it("children count", () => {
		let rootIns = create(
			<BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
				items={list}
				collapse={true}
				maxItems={2}
			/>
		).root;
		expect(rootIns.findAllByType("a").length).toEqual(1);
	});

	it("test the onCollapse props", () => {
		const mockFunction = jest.fn();
		let element = create(
			<BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
				items={list}
				collapse={true}
				maxItems={2}
				onCollapse={mockFunction}
			/>
		);
        element.root.props.onCollapse()
        expect(mockFunction).toHaveBeenCalled();
		let tree = element.toJSON();
		expect(tree).toMatchSnapshot();
	});

	// it("children count", () => {
	// 	const mockFunction = jest.fn();
	// 	let element = create(
	// 		<BreadCrumbs
	// 			seperator={'+'}
	// 			customId={'custom'}
	// 			active={list.length-1}
	// 			isFrontSeperator={true}
	// 			items={list}
	// 			collapse={true}
	// 			maxItems={2}
	// 		/>
	// 	);
	// 	expect(element.findAllByType("a").length).toEqual(list.length-2);
	// });

	it("children count", () => {
		const mockFunction = jest.fn();
		let element = <BreadCrumbs
				seperator={'+'}
				customId={'custom'}
				active={list.length-1}
				isFrontSeperator={true}
				items={list}
				collapse={true}
				maxItems={2}
				onCollapse={mockFunction}
			/>
		act(
			()=>{
				render(element,container)

				element.props.onCollapse()
				console.log(element.renderProps)
			}
		);
		//expect(element.children.length).toEqual(list.length-1);
	});
	
	// it('should trigger onClick',()=>{
	// 	const mockFunction = jest.fn();
	// 	const defprops={
	// 		seperator:'+',
	// 		customId:'customLink',
	// 		active:list.length-1,
	// 		isFrontSeperator:true,
	// 		items:list,
	// 		onSelect:mockFunction
	// 	}
	// 	const { props, renderedDOM } = setup(BreadCrumbs,defprops);
	// 	let currentElem = TestUtils.findRenderedComponentsWithTestid(renderedDOM,'customLink1_link');
	// 	TestUtils.Simulate.click(currentElem);
	// 	expect(props.onSelect.mock.calls.length).toBe(0);
	// })

	// it('should trigger onClick',()=>{
	// 	const mockFunction = jest.fn();
	// 	const defprops={
	// 		seperator:'+',
	// 		customId:'customLink',
	// 		active:list.length-1,
	// 		isFrontSeperator:true,
	// 		items:list,
	// 		onSelect:mockFunction
	// 	}
	// 	const { props, renderedDOM } = setup(BreadCrumbs,defprops);
	// 	let currentElem = TestUtils.findRenderedComponentsWithTestid(renderedDOM,'customLink0_link');
	// 	TestUtils.Simulate.click(currentElem);
	// 	expect(props.onSelect.mock.calls.length).toBe(1);
	// })
})