import React from 'react';
import Card from '../Card';
import renderer from 'react-test-renderer';
import AvatarConstantProps from '../../avatar/Avatar.constantProps';
import textConstantProps from '../../text/Text.constantProps';
import ButtonConstantProps from '@zohodesk/base/es/Button/props/propConstants';
import getDocIcon, { docsIcons } from '../../docsIcons';
import style from './Card.model.decorator.module.css';
import CardConstantProps from '../Card.constantProps';
import BoxConstantProps from '../../layout/Box.constantProps';
describe('Card component', () => {
  it('should card render primary', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.row} type={CardConstantProps.type.primary}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render secondary', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.row} type={CardConstantProps.type.secondary}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render success', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.row} type={CardConstantProps.type.success}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render danger', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.row} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render column', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.column} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render columnReverse', () => {
    let ele = renderer.create(
      <Card
        isContainer={true}
        direction={BoxConstantProps.direction.columnReverse}
        type={CardConstantProps.type.danger}
      >
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render row', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.row} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should card render rowReverse', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.rowReverse} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render FooterActions', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.rowReverse} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
        <Card.FooterActions align={BoxConstantProps.align.both}>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.shareLink, style.iconcolor)}
          </Card.Button>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.addLink, style.iconcolor)}
          </Card.Button>
        </Card.FooterActions>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render HeaderActions', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.rowReverse} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
        <Card.HeaderActions align={BoxConstantProps.align.both}>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.shareLink, style.iconcolor)}
          </Card.Button>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.addLink, style.iconcolor)}
          </Card.Button>
        </Card.HeaderActions>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render HeaderActions', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.rowReverse} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
        <Card.HeaderActions isHover align={BoxConstantProps.align.both}>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.shareLink, style.iconcolor)}
          </Card.Button>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.addLink, style.iconcolor)}
          </Card.Button>
        </Card.HeaderActions>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should card render HeaderActions', () => {
    let ele = renderer.create(
      <Card isContainer={true} direction={BoxConstantProps.direction.rowReverse} type={CardConstantProps.type.danger}>
        <Card.Avatar text='AE' size={AvatarConstantProps.size.small}></Card.Avatar>
        <Card.TextFields>
          <Card.PrimaryText variant={textConstantProps.variant.primary}>Albert Einstein</Card.PrimaryText>
          <Card.SecondaryText variant={textConstantProps.variant.secondary} textEllipsis={true}>
            alberteinstein@scientist.com
          </Card.SecondaryText>
        </Card.TextFields>
        ,<Card.Button>go</Card.Button>
        <Card.FooterActions isHover align={BoxConstantProps.align.both}>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.shareLink, style.iconcolor)}
          </Card.Button>
          <Card.Button variant={ButtonConstantProps.variant.plain} color={ButtonConstantProps.color.primary}>
            {getDocIcon(docsIcons.addLink, style.iconcolor)}
          </Card.Button>
        </Card.FooterActions>
      </Card>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});
