import React from 'react';
import PropTypes from 'prop-types';
import defaultStyle from './Button.module.css';
import buttonPropTypes, { defaultProps, propsDescription } from './Button.propTypes';
import constantProps from './Button.constantProps';
import getCompliedCustomId from '../../../utils/getCompliedCustomId';
import useButtonAriaProps from './useButtonAriaProps';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import buttonCssJSLogic from './Button.cssJSLogic';

export default function Button(props) {
  let { text, children, startIcon, endIcon, customStyle, customId, onClick, tagAttributes, tagGeneralAttributes } =
    props;

  let style = useMergeStyle(defaultStyle, customStyle);

  let hasIcon = startIcon || endIcon;

  let className = buttonCssJSLogic(props, style);

  let { buttonProps } = useButtonAriaProps(props);
  return (
    <button
      {...tagGeneralAttributes}
      className={className}
      data-id={getCompliedCustomId(props, customId.button)}
      onClick={onClick && onClick}
      {...buttonProps}
      {...tagAttributes}
    >
      <RenderAsIcon icon={startIcon} className={style.start_icon} />
      {text && hasIcon ? <span className={style.content_text}>{text}</span> : text || null}
      {!text && children ? children : null}
      <RenderAsIcon icon={endIcon} className={style.end_icon} />
    </button>
  );
}

Button.propTypes = buttonPropTypes;
Button.defaultProps = defaultProps;
Button.propsDescription = propsDescription;
Button.constantProps = constantProps;

const RenderAsIcon = (props) => {
  return props.icon ? <span className={props.className}>{props.icon}</span> : null;
};

RenderAsIcon.propTypes = {
  icon: PropTypes.any,
  className: PropTypes.string
};
