import React from 'react';
import Button from '../Button';
import renderer from 'react-test-renderer';
import constantProps from '../Button.constantProps';
import ReactTestUtils from 'react-dom/test-utils';

describe('Button component', () => {
  it('should display the text', () => {
    let ele = renderer.create(
      <Button text='Text button' size={constantProps.size.small} shape={constantProps.shape.circle} />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button', () => {
    let ele = renderer.create(
      <Button
        text='Text button'
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
        variant={constantProps.variant.contained}
        renderComponent={(props) => {
          let { variant, size, shape, text } = props;
          return <span className={`${style[size]} ${style[shape]} ${style[variant]}`}>{text}</span>;
        }}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the children', () => {
    let ele = renderer.create(
      <Button size={constantProps.size.small} shape={constantProps.shape.circle}>
        Children
      </Button>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-contained,color-primary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.contained}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should display the Button variant-outlined,color-primary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.outlined}
        variant={constantProps.variant.outlined}
        color={constantProps.color.primary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-text,color-primary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.plain}
        variant={constantProps.variant.plain}
        color={constantProps.color.primary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-contained,color-secondary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.contained}
        variant={constantProps.variant.contained}
        color={constantProps.color.secondary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-outlined,color-secondary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.outlined}
        variant={constantProps.variant.outlined}
        color={constantProps.color.secondary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-text,color-secondary', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.plain}
        variant={constantProps.variant.plain}
        color={constantProps.color.secondary}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-contained,color-danger', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.contained}
        variant={constantProps.variant.contained}
        color={constantProps.color.danger}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-outlined,color-danger', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.outlined}
        variant={constantProps.variant.outlined}
        color={constantProps.color.danger}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-text,color-danger', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.plain}
        variant={constantProps.variant.plain}
        color={constantProps.color.danger}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-contained,color-success', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.contained}
        variant={constantProps.variant.contained}
        color={constantProps.color.success}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-outlined,color-success', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.outlined}
        variant={constantProps.variant.outlined}
        color={constantProps.color.success}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button variant-text,color-success', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.variant.plain}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button size-sm', () => {
    let ele = renderer.create(
      <Button
        text='small'
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        size={constantProps.size.small}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button size-md', () => {
    let ele = renderer.create(
      <Button
        text='medium'
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button size-lg', () => {
    let ele = renderer.create(
      <Button
        text='large'
        size={constantProps.size.large}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button size-xl', () => {
    let ele = renderer.create(
      <Button
        text='xLarge'
        size={constantProps.size.xLarge}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        shape={constantProps.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button size-stretch', () => {
    let ele = renderer.create(
      <Button
        text={constantProps.size.stretch}
        size={constantProps.size.stretch}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button shape-default', () => {
    let ele = renderer.create(
      <Button
        text='+'
        shape={constantProps.shape.default}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        size={constantProps.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button shape-circle', () => {
    let ele = renderer.create(
      <Button
        text='+'
        shape={constantProps.shape.circle}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        size={constantProps.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button shape-oval', () => {
    let ele = renderer.create(
      <Button
        text='+'
        shape={constantProps.shape.oval}
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button shape-square', () => {
    let ele = renderer.create(
      <Button
        text='+'
        shape={constantProps.shape.square}
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button disabled', () => {
    let ele = renderer.create(
      <Button
        text='+'
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        disabled
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button active', () => {
    let ele = renderer.create(
      <Button
        text='+'
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        active
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button hover', () => {
    let ele = renderer.create(
      <Button
        text='+'
        size={constantProps.size.medium}
        variant={constantProps.variant.plain}
        color={constantProps.color.success}
        hovered
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('children count', () => {
    let rootIns = renderer.create(
      <Button
        text='Button'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      >
        <div>follow</div>
      </Button>
    ).root;
    expect(rootIns.findAllByType('button').length).toEqual(1);
  });
  it('should display the Icon component in start', () => {
    let ele = renderer.create(
      <Button
        variant={constantProps.variant.contained}
        size={constantProps.size.medium}
        shape={constantProps.shape.square}
        color={constantProps.color.success}
        startIcon='SI'
        text='Button'
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Icon component in end', () => {
    let ele = renderer.create(
      <Button
        variant={constantProps.variant.contained}
        size={constantProps.size.medium}
        shape={constantProps.shape.square}
        color={constantProps.color.success}
        text='Button'
        endIcon='EI'
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Icon component in start and end', () => {
    let ele = renderer.create(
      <Button
        variant={constantProps.variant.contained}
        size={constantProps.size.medium}
        shape={constantProps.shape.square}
        color={constantProps.color.success}
        startIcon='SI'
        text='Button'
        endIcon='EI'
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the Button hover', () => {
    let ele = renderer.create(
      <Button
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
        textEllipsis
        text="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book."
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should rendered the custom-id attributes', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        customId='customBtn'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the restorFocus true', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        restoreFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the restorFocus false', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        restoreFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should rendered the autoFocus true', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        autoFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the autoFocus false', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        autoFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  it('should rendered the focusClass', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        focusClass='focused'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the focusClass null', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        focusClass={null}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the custom-classname attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        customStyle={{
          size: 'size',
          shape: 'shape',
          variant: 'variant',
          color: 'color',
          textEllipsis: 'textEllipsis',
          cursor: 'cursor',
          active: 'active',
          hovered: 'hovered',
          disabled: 'disabled'
        }}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the aria-label attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaLabel='submit'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the role attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        role='button'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaLabelledby attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaLabelledby='follow'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaDisabled attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaDisabled='disabled'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaPressed attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaPressed='pressed'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaExpanded attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaExpanded='expanded'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaSelected attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaSelected='selected'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the ariaControls attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        ariaControls='control'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the focusClass attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        focusClass='focusClass'
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should rendered the restoreFocus attribute', () => {
    let ele = renderer.create(
      <Button
        text='Button'
        restoreFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('test the onclick props', () => {
    const mockFunction = jest.fn();
    const element = renderer.create(
      <Button
        text='Button'
        restoreFocus={true}
        size={constantProps.size.medium}
        variant={constantProps.variant.contained}
        color={constantProps.color.primary}
        shape={constantProps.shape.square}
        onClick={mockFunction}
      />
    );
    element.root.props.onClick();
    expect(mockFunction).toHaveBeenCalled();
  });
});
