import React from "react";
import DropDown, { DropDownContent, DropDownTarget } from "../DropDown";
import renderer from "react-test-renderer";
import positionMapping from "../DropDown.constantProps";
function CustomTarget(props) {
  let { togglePopup, getTargetRef } = props;
  return (
    <div
      ref={getTargetRef}
      onClick={togglePopup}
      style={{
        padding: "10px",
        border: "1px dashed pink",
        color: "pink"
      }}>
      Click Me
    </div>
  );
}

function DropDownTree(props) {
  let { togglePopup, getTargetRef } = props;
  return (
    <DropDown DropDownGroup='tree'>
      <DropDownTarget text='Click' isRemoveClose={true}></DropDownTarget>
      <DropDownContent color={positionMapping.color.danger}></DropDownContent>
    </DropDown>
  );

  // return null;
}
describe("DropDown component", () => {
  it("should default", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget text='small'></DropDownTarget>
        <DropDownContent></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Sizes
  it("should size as small", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget
          text='small'
          color={positionMapping.color.primary}></DropDownTarget>
        <DropDownContent size={positionMapping.size.small}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as medium", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget
          text='medium'
          color={positionMapping.color.primary}></DropDownTarget>
        <DropDownContent size={positionMapping.size.medium}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as large", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget
          text='large'
          color={positionMapping.color.primary}></DropDownTarget>
        <DropDownContent size={positionMapping.size.large}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as xlarge", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget
          text='xlarge'
          color={positionMapping.color.primary}></DropDownTarget>
        <DropDownContent size={positionMapping.size.xlarge}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // colors
  it("should size as xlarge", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget text='primary'></DropDownTarget>
        <DropDownContent
          size='default'
          color={positionMapping.color.primary}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as success", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget text='success'></DropDownTarget>
        <DropDownContent
          size='default'
          color={positionMapping.color.success}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as secondary", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget text='secondary'></DropDownTarget>
        <DropDownContent
          size={positionMapping.size.default}
          color={positionMapping.color.secondary}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as danger", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget text='danger'></DropDownTarget>
        <DropDownContent
          size={positionMapping.size.default}
          color={positionMapping.color.danger}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  {
    Object.keys(positionMapping.placement).forEach((val) => {
      it(`should placement as ${val}`, () => {
        let ele = renderer.create(
          <DropDown placement={val}>
            <DropDownTarget
              text={val}
              variant='outlined'
              color={positionMapping.color.success}></DropDownTarget>
            <DropDownContent></DropDownContent>
          </DropDown>
        );
        let tree = ele.toJSON();
        expect(tree).toMatchSnapshot();
      });
    });
  }

  it("should tree view ", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget>
          <CustomTarget />
        </DropDownTarget>
        <DropDownContent color={positionMapping.color.danger}>
          <DropDownTree />
        </DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should custom target ", () => {
    let ele = renderer.create(
      <DropDown>
        <DropDownTarget>
          <CustomTarget />
        </DropDownTarget>
        <DropDownContent color={positionMapping.color.danger}></DropDownContent>
      </DropDown>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});
