import React from "react";
import Link from "../Link";
import renderer from "react-test-renderer";
import linkConstants from "../Link.constantProps";
import { create, act } from "react-test-renderer";

describe("Link component", () => {
  // varients
  it("should display the content with varient as default", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.default}
        size={linkConstants.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with varient as primary", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with varient as secondary", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.secondary}
        size={linkConstants.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // sizes
  it("should display the content with size as xSmall", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.xSmall}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with size as small", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.small}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with size as medium", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.medium}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with size as large", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with size as xLarge", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.xLarge}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with size as xxLarge", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.xxLarge}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Text Decoration
  it("should display the content with textDecoration as overLine", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        textDecoration={linkConstants.textDecoration.overLine}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with textDecoration as underLine", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        textDecoration={linkConstants.textDecoration.underLine}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content with textDecoration as lineThrough", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        textDecoration={linkConstants.textDecoration.lineThrough}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // start and end child supports
  it("should display the children component in start ", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        startIcon="StartIcon"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the children component in end ", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        endIcon="EndIcon"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the children component in start and end", () => {
    let ele = renderer.create(
      <Link
        color={linkConstants.colors.primary}
        size={linkConstants.size.large}
        startIcon="StartIcon"
        endIcon="EndIcon"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Ellipsis
  it("should display the component content with textEllipsis support", () => {
    let ele = renderer.create(
      <Link
        textEllipsis
        text="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book."
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Word Wrap
  it("should display the component content with wordWrap support", () => {
    let ele = renderer.create(
      <Link
        wordWrap
        text="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book."
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  // Custom i'd & ClassName
  it("should rendered the custom-id and custom-classname attributes", () => {
    let ele = renderer.create(
      <Link href={document.location.href} text="Link" customId="customLink" />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // active,visited,focused and hovered
  it("should check the state as active", () => {
    let ele = renderer.create(
      <Link href={document.location.href} text="Link" active />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should check the state as visited", () => {
    let ele = renderer.create(
      <Link href={document.location.href} text="Link" visited />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should check the state as focused", () => {
    let ele = renderer.create(
      <Link href={document.location.href} text="Link" focused />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should check the state as hovered", () => {
    let ele = renderer.create(
      <Link href={document.location.href} text="Link" hovered />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Onclick support'
  it("test the onclick props", () => {
    const mockFunction = jest.fn();
    const element = renderer.create(
      <Link href={document.location.href} text="Link" onClick={mockFunction} />
    );
    element.root.findByType("a").props.onClick();
    expect(mockFunction).toHaveBeenCalled();
  });
  // children count'
  it("children count", () => {
    let rootIns = create(
      <Link text="Link">
        <div>awecome content</div>
      </Link>
    ).root;
    expect(rootIns.findAllByType("a").length).toEqual(1);
  });
});
