import React from 'react';
import ListItem from '../ListItem';
import renderer from 'react-test-renderer';
import listitemConstants from '../ListItem.constantProps';
import { create, act } from 'react-test-renderer';

let menuItemProps = (value, disabled) => {
  return {
    role: 'option',
    tabIndex: '0'
  };
};
describe('ListItem component', () => {
  it('should render the given ListItem as size:small,variant:primary,text:List', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='List'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.primary}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.text).toBe('List');
  });
  // variants
  it('should render the given ListItem as size:small,variant:primary', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.primary}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.variant).toBe('var_Primary');
  });
  it('should render the given ListItem as size:small,variant:secondary', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.secondary}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.variant).toBe('var_Secondary');
  });
  //sizes
  it('should render the given ListItem as size:small,variant:secondary', () => {
    let ele = renderer.create(
      <ListItem size={listitemConstants.size.small} text='list' variant={listitemConstants.variant.secondary} />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.size).toBe('size_sm');
  });
  it('should render the given ListItem as size:medium,variant:secondary', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.medium}
        text='list'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.secondary}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.size).toBe('size_md');
  });
  it('should render the given ListItem as size:large,variant:secondary', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.large}
        text='list'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.secondary}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.size).toBe('size_lg');
  });

  it('should render the given ListItem as size:large,variant:secondary,disabled', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.large}
        text='list'
        menuItemProps={menuItemProps}
        variant={listitemConstants.variant.secondary}
        disabled={true}
      />
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.disabled).toBe(true);
  });

  it('should render the given ListItem with children', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        variant={listitemConstants.variant.primary}
        menuItemProps={menuItemProps}
        onChange={() => {}}
      >
        <span>subTitle</span>
      </ListItem>
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.children).toBe(<span>subTitle</span>);
  });
  it('should render the given ListItem with menuitemprops', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        variant={listitemConstants.variant.primary}
        menuItemProps={menuItemProps}
        onChange={() => {}}
      >
        <span>subTitle</span>
      </ListItem>
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.menuItemProps.role).toBe('option');
  });
  it('should render the given ListItem with children', () => {
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        variant={listitemConstants.variant.primary}
        menuItemProps={menuItemProps}
        onChange={() => {}}
      >
        <span>subTitle</span>
      </ListItem>
    );
    const testInstance = ele.root;
    expect(testInstance.findByType(ListItem).props.menuItemProps.tabIndex).toBe(0);
  });
  it('should render the given ListItem with children', () => {
    const mockFunction = jest.fn();
    let ele = renderer.create(
      <ListItem
        size={listitemConstants.size.small}
        text='list'
        variant={listitemConstants.variant.primary}
        menuItemProps={menuItemProps}
        onChange={mockFunction}
      >
        <span>subTitle</span>
      </ListItem>
    );

    element.root.props.onChange();
    expect(mockFunction).toHaveBeenCalled();
    // let tree = element.toJSON();

    // const testInstance = ele.root;
    // expect(testInstance.findByType(ListItem).props.menuItemProps.tabIndex).toBe(0);
  });
});
