import React, { useEffect, useState } from 'react';
import defaultStyle from './MultiSelect.module.css';
import multiSelectConstants from './MultiSelect.constantProps';
import multiSelectPropTypes, { defaultProps, propsDescription } from './MultiSelect.propTypes';
import ListItem, { ListBox } from '../listitem/ListItem';
import ListItemPropTypes, {
  defaultProps as listItemDefaultProps,
  propsDescription as listItemPropsDescription
} from '../listitem/ListItem.propTypes';
import ListItemConstants from '../listitem/ListItem.constantProps';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import multiSelectCssJSLogic from './MultiSelect.cssJSLogic';

export default function MultiSelect(props) {
  let {
    children,
    isPopupOpen,
    togglePopup,
    selectedOptionsRenderer,
    selectedValues = [],
    onHandleRemove,
    disabled,
    readonly,
    customStyle = {},
    onkeydown,
    placeholder,
    emptyStateComponent,
    valueProps,
    triggerProps,
    selectedItemProps,
    rootElementProps,
    filteredOptions = [],
    isLoadingState,
    loadingStateComponent,
    isEmptyState,
    tagGeneralAttributes: { triggerGeneralAttributes = {}, menuGeneralAttributes = {} },
    tagAttributes: { triggerTagAttributes = {}, menuTagAttributes = {} }
  } = props;
  const [suggestions, setSuggestions] = useState([]);

  let style = useMergeStyle(defaultStyle, customStyle);

  let classNames = multiSelectCssJSLogic(props, style);

  let tagprops = {
    variant: 'outlined',
    color: 'primary',
    size: 'small',
    onHandleRemove,
    selectedValues,
    selectedItemProps,
    ...valueProps,
    onkeydown
  };
  useEffect(() => {
    setSuggestions(selectedOptionsRenderer(tagprops));
  }, [selectedValues.length]);
  return (
    <div
      className={classNames}
      onClick={disabled || readonly ? null : togglePopup}
      {...triggerGeneralAttributes}
      {...valueProps}
      {...triggerProps}
      {...triggerTagAttributes}
    >
      <div className={style.multiselectedContent} {...rootElementProps}>
        {suggestions}
        <span className={style.placeholder}>{placeholder}</span>
      </div>
      {isPopupOpen ? (
        <div className={style.optionContainer}>
          <ListBox
            tagGeneralAttributes={menuGeneralAttributes}
            isEmptyState={!filteredOptions.length}
            emptyState={emptyStateComponent}
            isLoadingState={isLoadingState}
            loadingState={loadingStateComponent}
            isEmpty={children.length}
            {...props}
            tagAttributes={menuTagAttributes}
          >
            {children}
          </ListBox>
        </div>
      ) : null}
    </div>
  );
}

export function OptionSkeleton(props) {
  let { value, onHandleSelect, removeClose, isIgnore, tagGeneralAttributes, tagAttributes } = props;
  return isIgnore ? (
    <ListItem
      tagGeneralAttributes={tagGeneralAttributes}
      {...props}
      onChange={(e, value) => {
        onHandleSelect(value);
        removeClose(e);
      }}
      tagAttributes={tagAttributes}
    />
  ) : null;
}
OptionSkeleton.displayName = 'Option';
OptionSkeleton.propTypes = ListItemPropTypes;
OptionSkeleton.defaultProps = listItemDefaultProps;
OptionSkeleton.propsDescription = listItemPropsDescription;
OptionSkeleton.constantProps = ListItemConstants;

export function selectedOptionSkeleton(props) {
  let { color, variant, size, shape, onHandleRemove, selectedValues } = props;
  if (selectedValues.length) {
    return (
      selectedValues.length &&
      selectedValues.map((val, i) => {
        return (
          <Tag
            color={color}
            variant={variant}
            size={size}
            shape={shape}
            text={val}
            tabIndex={0}
            endIcon={
              <Icon
                onClick={() => {
                  onHandleRemove(val);
                }}
              />
            }
          />
        );
      })
    );
  } else {
    return null;
  }
}

MultiSelect.propTypes = multiSelectPropTypes;
MultiSelect.defaultProps = defaultProps;
MultiSelect.propsDescription = propsDescription;
MultiSelect.constantProps = multiSelectConstants;
