import React, { useEffect, useState } from 'react';
import defaultStyle from './NotificationBadge.module.css';
import { abbreviateNumber } from '../../libraries/AbbreviateNumber';
import NotificationBadgePropTypes, { defaultProps } from './NotificationBadge.propTypes';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import notificationBadgeCssJSLogic from './NotificationBadge.cssJSLogic';

export default function NotificationBadgeSkeleton(props) {
  const [displayCountText, changeCountText] = useState('');
  let {
    text,
    children,
    count,

    icon,
    onClick,

    tagAttributes,
    tagGeneralAttributes,

    customStyle,
    customId,
    ariaLabel
  } = props;

  let style = useMergeStyle(defaultStyle, customStyle);

  let ariaLabelValue = ariaLabel || text;

  let className = notificationBadgeCssJSLogic(props, style);

  useEffect(() => {
    let displayCount = props.count && abbreviateNumber(props.count);
    displayCount && changeCountText(displayCount);
  }, []);
  return (
    <span className={style.container} aria-label={ariaLabelValue} data-id={customId} onClick={onClick}>
      <span {...tagGeneralAttributes} className={className} {...tagAttributes}>
        {icon && icon}
        {count && displayCountText}
        {text && text}
        {children && children}
      </span>
    </span>
  );
}

NotificationBadgeSkeleton.propTypes = NotificationBadgePropTypes;
NotificationBadgeSkeleton.defaultProps = defaultProps;
