import React from 'react';
import NotificationBadge from '../NotificationBadge';
import renderer from 'react-test-renderer';
import notificationBadgeConstants from '../NotificationBadge.constantProps';
import { create, act } from 'react-test-renderer';

describe('Notification Badge component', () => {
  // varients
  it('should display the content with varient as default', () => {
    let ele = renderer.create(<NotificationBadge count={700000} size={notificationBadgeConstants.size.large} />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  // size
  it('should display the content with size as small', () => {
    let ele = renderer.create(<NotificationBadge count={700000} size={notificationBadgeConstants.size.small} />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the content with size as medium', () => {
    let ele = renderer.create(<NotificationBadge count={700000} size={notificationBadgeConstants.size.medium} />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the content with size as large', () => {
    let ele = renderer.create(<NotificationBadge count={700000} size={notificationBadgeConstants.size.large} />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // shapes
  it('should display the content with shape as circle', () => {
    let ele = renderer.create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.small}
        shape={notificationBadgeConstants.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display the content with shape as square', () => {
    let ele = renderer.create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.medium}
        shape={notificationBadgeConstants.shape.circle}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Icon
  it('should display the content with shape as circle', () => {
    let ele = renderer.create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.small}
        shape={notificationBadgeConstants.shape.square}
        Icon={'Icon'}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Accessibility
  it('should display the content with shape as circle', () => {
    let ele = renderer.create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.small}
        shape={notificationBadgeConstants.shape.square}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Onclick support'
  it('test the onclick props', () => {
    const mockFunction = jest.fn();
    const element = renderer.create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.small}
        shape={notificationBadgeConstants.shape.square}
        onClick={mockFunction}
      />
    );
    element.root.findByType('span').props.onClick();
    expect(mockFunction).toHaveBeenCalled();
  });
  // children count'
  it('children count', () => {
    let rootIns = create(
      <NotificationBadge
        count={700000}
        size={notificationBadgeConstants.size.small}
        shape={notificationBadgeConstants.shape.square}
      >
        <div>children</div>
      </NotificationBadge>
    ).root;

    expect(rootIns.findAllByType('span').length).toEqual(2);
  });
});
