import React from 'react';

import defaultStyle from './Popup.module.css';
import positionMapping from './__popupstylemapping';
import Button from '@zohodesk/base/es/Button/Button';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import popupCssJSLogic from './Popup.cssJSLogic';
import popupContentCssJsLogic from './PopupContent.cssJSLogic';

// MOM
// elements ref based rendering for fixed content and target (isAbsolutePositioningNeeded docs)
// customize the order of placements (customPositionOrder props related docs)
// content will be render in root level if needed related customizations (todo)
// expose target and content related element-rect-bound details
// loading cases if chunk related delay happens
// fixed-popup will be close hooks if document or any elements while scroll
// content area will be wrk based on configuration (absolute or fixed), He explained select component cases

export default function PopupSkeleton(props) {
  let { childrenWithPropsData, customStyle = {}, tagGeneralAttributes, tagAttributes } = props;

  let styles = useMergeStyle(defaultStyle, customStyle);

  let classNames = popupCssJSLogic(props, styles);

  // tagname and component render support (skeleton custom) (todo)
  return (
    <div {...tagGeneralAttributes} className={classNames} {...tagAttributes}>
      {childrenWithPropsData}
    </div>
  );
}

export function PopupTargetSkeleton(props) {
  let { children, getTargetRef, handleToggle, targetProps } = props;

  if (children) {
    const childrenWithPropsTarget = React.Children.map(children, (child, index) => {
      return React.cloneElement(child, props);
    });
    return <>{childrenWithPropsTarget}</>;
  }
  return (
    <Button
      tagGeneralAttributes={{
        ref: getTargetRef
      }}
      tagAttributes={targetProps}
      onClick={(e) => {
        handleToggle(e);
      }}
      {...props}
    />
  );
}

export function PopupContentSkeleton(props) {
  let {
    children,
    togglePopup,
    isPopupOpen,
    removeClose,
    position,
    arrowPosition,
    placement,
    color,
    size,
    getContainerRef,
    hasArrow,
    contentProps,
    customStyle,
    tagGeneralAttributes,
    tagAttributes
  } = props;

  let styles = useMergeStyle(defaultStyle, customStyle);

  let classNames = popupContentCssJsLogic(props, styles);

  let boxPosition = placement ? placement : position;
  const boxDirection = positionMapping[boxPosition].direction;
  arrowPosition = arrowPosition ? arrowPosition : positionMapping[boxPosition].arrowPosition;
  boxPosition = positionMapping[boxPosition].positionStyle;
  // let contentSize = styles[size];
  // let colorStyle = styles[color];

  const renderChildren = React.Children.map(children, (child, i) => {
    return React.cloneElement(child, {
      key: i,
      isPopupOpen,
      togglePopup
    });
  });

  if (isPopupOpen) {
    return (
      <div
        {...tagGeneralAttributes}
        {...contentProps}
        ref={getContainerRef}
        className={`${styles.popupSubContainer} ${styles[boxPosition]} ${styles[boxDirection]}  ${
          styles[`arrow${boxDirection}`]
        }`}
        onClick={removeClose}
        {...tagAttributes}
      >
        <div className={classNames}>
          {hasArrow ? (
            <span className={styles[arrowPosition]}>
              <span className={styles.arrowShape} />
            </span>
          ) : null}
          {renderChildren}
        </div>
      </div>
    );
  }
  return null;
}
