import React from "react";
import Popup, { PopupContent, PopupTarget } from "../Popup";
import renderer from "react-test-renderer";
import positionMapping from "../Popup.constantProps";
function CustomTarget(props) {
  let { togglePopup, getTargetRef } = props;
  return (
    <div
      ref={getTargetRef}
      onClick={togglePopup}
      style={{
        padding: "10px",
        border: "1px dashed pink",
        color: "pink"
      }}
    >
      Click Me
    </div>
  );
}

function PopupTree(props) {
  let { togglePopup, getTargetRef } = props;
  return (
    <Popup popupGroup="tree">
      <PopupTarget text="Click" isRemoveClose={true}></PopupTarget>
      <PopupContent color={positionMapping.color.danger}></PopupContent>
    </Popup>
  );

  // return null;
}
describe("Popup component", () => {
  it("should default", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget text="small"></PopupTarget>
        <PopupContent></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // Sizes
  it("should size as small", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget
          text="small"
          color={positionMapping.color.primary}
        ></PopupTarget>
        <PopupContent size={positionMapping.size.small}></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as medium", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget
          text="medium"
          color={positionMapping.color.primary}
        ></PopupTarget>
        <PopupContent size={positionMapping.size.medium}></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as large", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget
          text="large"
          color={positionMapping.color.primary}
        ></PopupTarget>
        <PopupContent size={positionMapping.size.large}></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should size as xlarge", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget
          text="xlarge"
          color={positionMapping.color.primary}
        ></PopupTarget>
        <PopupContent size={positionMapping.size.xlarge}></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  // colors
  it("should size as xlarge", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget text="primary"></PopupTarget>
        <PopupContent
          size="default"
          color={positionMapping.color.primary}
        ></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as success", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget text="success"></PopupTarget>
        <PopupContent
          size="default"
          color={positionMapping.color.success}
        ></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as secondary", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget text="secondary"></PopupTarget>
        <PopupContent
          size={positionMapping.size.default}
          color={positionMapping.color.secondary}
        ></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should color as danger", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget text="danger"></PopupTarget>
        <PopupContent
          size={positionMapping.size.default}
          color={positionMapping.color.danger}
        ></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });

  {
    Object.keys(positionMapping.placement).forEach((val) => {
      it(`should placement as ${val}`, () => {
        let ele = renderer.create(
          <Popup placement={val}>
            <PopupTarget
              text={val}
              variant="outlined"
              color={positionMapping.color.success}
            ></PopupTarget>
            <PopupContent></PopupContent>
          </Popup>
        );
        let tree = ele.toJSON();
        expect(tree).toMatchSnapshot();
      });
    });
  }

  it("should tree view ", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget>
          <CustomTarget />
        </PopupTarget>
        <PopupContent color={positionMapping.color.danger}>
          <PopupTree />
        </PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should custom target ", () => {
    let ele = renderer.create(
      <Popup>
        <PopupTarget>
          <CustomTarget />
        </PopupTarget>
        <PopupContent color={positionMapping.color.danger}></PopupContent>
      </Popup>
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});
