import React, { useState, useEffect, useRef } from 'react';
import TextBox from '../../textbox/TextBox';
import defaultStyle from '../Select.module.css';

import { ListBox } from '../../listitem/ListItem';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import selectCssJSLogic from '../Select.cssJSLogic';
import ArrowFillDown from '@zohodesk/icon/es/general/ArrowFillDown';

export default function SelectWithSearchSkeleton(props) {
  let {
    customStyle = {},
    children,
    selectedValue,
    searchValue,
    icon,

    //Popup component props
    isPopupOpen,
    togglePopup,
    getTargetRef,
    getContainerRef,

    //Accessiblity
    triggerProps,
    valueProps,
    menuProps,
    rootElementProps,
    inputProps,
    getInputRef,

    //
    removeClose,
    emptyState, //for showing empty options
    onSearch, //for filtering options hooks
    onSearchChange, //for listen TextBox onchange,
    onSetSearchValue,
    searchPlaceholder, //for TextBox search placeholder
    customSearchBox, // replacing textbox
    tagGeneralAttributes: { triggerGeneralAttributes = {}, menuGeneralAttributes = {}, searchGeneralAttributes = {} },
    tagAttributes: { triggerTagAttributes = {}, menuTagAttributes = {}, searchTagAttributes = {} }
  } = props;

  let style = useMergeStyle(defaultStyle, customStyle);

  let { selectClassName, selectIconClassName, listboxClassName } = selectCssJSLogic(props, style);

  // let arrowDownIcon = icon || <ArrowFillDown customStyle={{base : isPopupOpen? style.arrowRotate: style.arrowIcon}}/>;

  return (
    <div className={style.baseSearch} {...rootElementProps}>
      <div
        {...triggerGeneralAttributes}
        className={selectClassName}
        onClick={togglePopup}
        ref={getTargetRef}
        {...valueProps}
        {...triggerProps}
        {...triggerTagAttributes}
      >
        {selectedValue}
        {/* <div>{selectedValue}</div>
          {arrowDownIcon && <span className={selectIconClassName}>{arrowDownIcon}</span>} */}
      </div>

      {isPopupOpen ? (
        <div
          className={`${style.optionContainerSearch} ${listboxClassName}`}
          onClick={removeClose}
          ref={getContainerRef}
        >
          <div className={style.searchBox}>
            {!customSearchBox ? (
              <TextBox
                variant={TextBox.constantProps.variant.flushed}
                tagGeneralAttributes={searchGeneralAttributes}
                onFocus={removeClose}
                value={searchValue}
                className={style.input}
                onChange={(value, e) => {
                  onSetSearchValue && onSetSearchValue(value);
                  onSearchChange && onSearchChange(value);
                }}
                getRef={getInputRef}
                placeholder={searchPlaceholder}
                {...inputProps}
                tagAttributes={searchTagAttributes}
              ></TextBox>
            ) : (
              customSearchBox(props)
            )}
          </div>
          <ListBox
            tagGeneralAttributes={menuGeneralAttributes}
            {...props}
            {...menuProps}
            className={style.flexAuto}
            tagAttributes={menuTagAttributes}
          >
            {children}
          </ListBox>
        </div>
      ) : null}
    </div>
  );
}
