import React from "react";
import styles from "./Tab.module.css";
import getCompliedClassName from "../../utils/getCompliedClassName";

export function TabContainerLayer(props) {
  let { customClassName = {}, children } = props;
  let tabContainerClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tabContainer]: true
    },
    {
      [customClassName.tabContainer]: customClassName.tabContainer
    }
  );

  return (
    <div className={tabContainerClassName}>
      {children}
    </div>
  );
}

export default function TabContainer(props) {
  let { children } = props;
  return <TabContainerLayer {...props}> {children} </TabContainerLayer>
}

export function TabContext(props) {
  return <TabContainerLayer {...props}> {props.children} </TabContainerLayer>
}

export function TabBar(props) { 
  let { children,customClassName={},tabListAriaProps } = props;
  let tabBarClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tabBar]: true
    },
    {
      [customClassName.tabBar]: customClassName.tabBar
    }
  );
  return <div className={tabBarClassName} {...tabListAriaProps}>
    { children }
    </div>
}

export function TabBarNavLine(props){
  let { children,customClassName={},navLineRef,tabListAriaProps } = props;
  let tabBarClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tabBarNavBase]: true
    },
    {
      [customClassName.tabBar]: customClassName.tabBar
    }
  );
  return(
    <div className={tabBarClassName} {...tabListAriaProps}>
      {children}
      <div className={styles.navLine} ref={navLineRef}></div>
    </div>
  ) 
}

export function Tab(props) {
  let {
    onChange,
    children,
    disabled,
    customClassName={},
    getRef,
    tabAriaProps,
    active,
    focusProps
  } = props;
  let tabClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tab]: true && !customClassName.tab,
      [styles.tabSelect] : active && !customClassName.selected,
      [styles.tabDisabled] : !!disabled && !customClassName.disabled
    },
    {
      [customClassName.tab]: !!customClassName.tab,
      [customClassName.selected]: active && !!customClassName.selected,
      [customClassName.disabled]: !!customClassName.disabled
    }
  )
  return <div onClick={!disabled ? onChange : null} className={tabClassName} ref={getRef} {...tabAriaProps} {...focusProps}>
    {children}
  </div>
}

export function TabWithIcon(props){
  let { 
    tabCondition,
    onChange,
    selectedValue,
    value,
    children,
    customClassName={},
    getRef
   } = props;
  let selectedTab = tabCondition(value,selectedValue);
  let tabClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tab]: true,
      [styles.tabSelect] : selectedTab 
    },
    {
      [customClassName.tab]: customClassName.tab,
      [customClassName.selected]: selectedTab && customClassName.selected
    }
  )
  return(
    <div onClick={onChange && onChange.bind(null,value)} className={tabClassName} ref={getRef}>
      { children }
    </div>
  )
}

export function TabContent(props) {
  let { children,customClassName={} } = props;
  let tabContentClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tabContent]: true
    },
    {
      [customClassName.tabContent]: customClassName.tabContent
    }
  )
  return <div className={tabContentClassName}>{ children }</div>
}

export function TabPanel(props) {
  let { selectedValue,value,tabCondition,children,customClassName={},tabPanelAriaProps } = props;
  let selectedTab = tabCondition(value,selectedValue);
  let tabPanelClassName = getCompliedClassName(
    customClassName,
    {
      [styles.tabPanel]: true
    },
    {
      [customClassName.tabPanel]: customClassName.tabPanel
    }
  )
  return selectedTab ? <div className={tabPanelClassName} {...tabPanelAriaProps}>{children}</div> : null;
}
