import React from 'react';
import PropTypes from 'prop-types';
import useMergeStyle from '@zohodesk/hooks/es/utils/useMergeStyle';
import defaultStyle from './Tag.module.css';
import getCompliedCustomId from '../../utils/getCompliedCustomId';
import tagPropTypes, { defaultProps, propsDescription } from './Tag.propTypes';
import constantProps from './Tag.constantProps';
import tagCssJSLogic from './Tag.cssJSLogic';

export default function Tag(props) {
  const {
    text,
    title,
    children,

    value,

    startIcon,
    endIcon,

    customStyle,
    customId,

    ariaLabel,
    role = 'tag',
    tabIndex,
    tagItemProps,

    tagAttributes,
    tagGeneralAttributes
  } = props;

  const style = useMergeStyle(defaultStyle, customStyle);

  const ariaLabelValue = ariaLabel || text;

  const className = tagCssJSLogic(props, style);

  return (
    <span
      {...tagGeneralAttributes}
      className={className}
      data-id={getCompliedCustomId(props, customId.tag)}
      aria-label={ariaLabelValue}
      {...tagItemProps}
      role={role}
      tabIndex={tabIndex}
      title={title || text}
      value={value}
      {...tagAttributes}
    >
      <RenderAsIcon icon={startIcon} className={style.start_icon} />
      {text && (startIcon || startIcon) ? <span>{text}</span> : text || null}
      {!text && children ? children : null}
      <RenderAsIcon icon={endIcon} className={style.end_icon} />
    </span>
  );
}

Tag.propTypes = tagPropTypes;
Tag.defaultProps = defaultProps;
Tag.propsDescription = propsDescription;
Tag.constantProps = constantProps;

const RenderAsIcon = (props) => (props.icon ? <span className={props.className}>{props.icon}</span> : null);

RenderAsIcon.propTypes = {
  icon: PropTypes.any,
  className: PropTypes.string
};
