import React from 'react';
import Text from '../Text';
import renderer from 'react-test-renderer';
import textConstants from '../Text.constantProps';
import getDocIcon, { docsIcons } from "../../docsIcons";

describe("Text component", () => {
  it("should display the content", () => {
    let ele = renderer.create(<Text content="Lorem Ipsum is simply dummy text" />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content -null", () => {
    let ele = renderer.create(<Text content={null} />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in overflow hidden", () => {
    let ele = renderer.create(<Text
      textEllipsis={true}
      content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in overflow hidden", () => {
    let ele = renderer.create(<Text
      textEllipsis={false}
      content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in wrap", () => {
    let ele = renderer.create(<Text
      wordWrap={true}
      content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in wrap", () => {
    let ele = renderer.create(<Text
      wordWrap={false}
      content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight xsmall", () => {
    let ele = renderer.create(<Text
      content="font-weight : xs"
      weight={textConstants.weight.xSmall}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight small", () => {
    let ele = renderer.create(<Text
      content="font-weight : sm"
      weight={textConstants.weight.small}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight medium", () => {
    let ele = renderer.create(<Text
      content="font-weight : md"
      weight={textConstants.weight.medium}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight large", () => {
    let ele = renderer.create(<Text
      content="font-weight : lg"
      weight={textConstants.weight.large}
      />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight xLarge", () => {
    let ele = renderer.create(<Text
      content="font-weight : xl"
      weight={textConstants.weight.xLarge}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight bold", () => {
    let ele = renderer.create(<Text
      content="font-weight : bold"
      weight={textConstants.weight.bold}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight normal", () => {
    let ele = renderer.create(<Text
      content="font-weight : normal"
      weight={textConstants.weight.normal}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the weight lighter", () => {
    let ele = renderer.create(
    <Text
      content="font-weight : lighter"
      weight={textConstants.weight.lighter}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading", () => {
    let ele = renderer.create(  
    <Text
      tagName="h4"
      content="Tag Name : H4"
    />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in div", () => {
    let ele = renderer.create(
      <Text
        tagName="div"
        content="Tag Name : Div"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in paragraph", () => {
    let ele = renderer.create(
      <Text
        tagName="p"
        content="Tag Name : P"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content span tag", () => {
    let ele = renderer.create(
      <Text
        tagName="span"
        content="Tag Name : Span"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in link tag", () => {
    let ele = renderer.create(
      <Text
        tagName="a"
        content="Tag Name : A"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the align left", () => {
    let ele = renderer.create(
      <Text
        tagName="div"
        content="text-align : left"
        align={textConstants.align.left}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the align right", () => {
    let ele = renderer.create(
      <Text
        tagName="div"
        content="text-align : right"
        align={textConstants.align.right}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the align center", () => {
    let ele = renderer.create(
      <Text
        tagName="div"
        content="text-align : center"
        align={textConstants.align.center}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size xSmall", () => {
    let ele = renderer.create(<Text
      content="xSmall size content"
      size={textConstants.size.xSmall}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size small", () => {
    let ele = renderer.create(<Text
      content="small size content"
      size={textConstants.size.small}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size medium", () => {
    let ele = renderer.create(<Text
      content="medium size content"
      size={textConstants.size.medium}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size large", () => {
    let ele = renderer.create(<Text
      content="lg size content"
      size={textConstants.size.large}
      />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size xLarge", () => {
    let ele = renderer.create(<Text
      content="xl size content"
      size={textConstants.size.xLarge}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the size xxLarge", () => {
    let ele = renderer.create(<Text
      content="xxl size content"
      size={textConstants.size.xxLarge}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in Capital letters", () => {
    let ele = renderer.create(
      <Text
        content="text-transform:uppercase"
        transform="uppercase"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in small letters", () => {
    let ele = renderer.create(
    <Text
      content="text-transform:lowercase"
      transform="lowercase"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the first character of the content in Capital", () => {
    let ele = renderer.create(
    <Text
        content="text-transform:capitalize"
        transform="capitalize"   
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  
  it("should display the content in h1 tag", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        tagName="h1"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in h2 tag", () => {
    let ele = renderer.create(
    <Text
    content="Lorem Ipsum is simply dummy"
    tagName="h2"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in h3 tag", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      tagName="h3"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in h4 tag", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        tagName="h4"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in h5 tag", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      tagName="h5"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in h6 tag", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      tagName="h6"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the heading", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        heading="large"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the variant primary", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      variant="primary"
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the variant secondary", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        variant="secondary"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the text color darknight", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      colorPalette={textConstants.colorPalette.darknight}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the text color success", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        colorPalette={textConstants.colorPalette.success}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the text color info", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      colorPalette={textConstants.colorPalette.info}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the text color danger", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        colorPalette={textConstants.colorPalette.danger}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the text color lighter", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      colorPalette={textConstants.colorPalette.lighter}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the text color grayness", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        colorPalette={textConstants.colorPalette.grayness}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the text color highLight", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      colorPalette={textConstants.colorPalette.highLight}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the text color whiteness", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        colorPalette={textConstants.colorPalette.whiteness}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration overLine ", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.overLine}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the decoration underLine ", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      decoration={textConstants.decoration.underLine}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration lineThrough", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.lineThrough}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
    
  it("should display the decoration underLine,decorationColor darknight", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      decoration={textConstants.decoration.underLine}
      decorationColor={textConstants.decorationColor.darknight}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration underLine,decorationColor success", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.underLine}
        decorationColor={textConstants.decorationColor.success}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration underLine,decorationColor info", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      decoration={textConstants.decoration.underLine}
      decorationColor={textConstants.decorationColor.info}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration underLine,decorationColor danger", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.underLine}
        decorationColor={textConstants.decorationColor.danger}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the decoration underLine,decorationColor lighter", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      decoration={textConstants.decoration.underLine}
      decorationColor={textConstants.decorationColor.lighter}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration underLine,decorationColor grayness", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.underLine}
        decorationColor={textConstants.decorationColor.grayness}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });  
  it("should display the decoration underLine,decorationColor highLight", () => {
    let ele = renderer.create(
    <Text
      content="Lorem Ipsum is simply dummy"
      decoration={textConstants.decoration.underLine}
      decorationColor={textConstants.decorationColor.highlight}
    />);
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the decoration underLine,decorationColor whiteness", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        decoration={textConstants.decoration.underLine}
        decorationColor={textConstants.decorationColor.whiteness}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  
  it("should display the indent small", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        indent={textConstants.indent.small}
        tagName="div"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  
  it("should display the indent medium", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        indent={textConstants.indent.medium}
        tagName="div"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  
  it("should display the indent large", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        indent={textConstants.indent.large}
        tagName="div"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  
  it("should display the customStyle", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle="customStyle123"
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle -base", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{base:'base'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle -textEllipsis", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{textEllipsis:'textEllipsis'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle-wordwrap", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{wordWrap:"wordWrap"}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle-variant", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{variant:'Variant'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-size", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{size:'size'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-align", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{align:'align'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-weight", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{weight:"weight"}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-transform", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{transform:'transform'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-colorPalette", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{colorPalette:'colorPalette'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-lineHeight", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{lineHeight:'lineHeight'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-letterSpacing", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{letterSpacing:'letterSpacing'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-decoration", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{decoration:'decoration'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle-decorationColor", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{decorationColor:'decorationColor'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });it("should display the customStyle-indent", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{indent:'indent'}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the customStyle", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        customStyle={{}}
        customIdPrefix="customText"
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the tabindex", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        tabIndex='1'
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the tabindex-1", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        tabIndex='-1'
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the renderComponent", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        renderComponent={(props)=>(<div>{props.content}</div>)}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the renderComponent-null", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        renderComponent={null}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level1", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.one}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level2", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.two}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level3", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.three}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level4", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.four}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level5", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.five}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content as heading -level6", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy"
        type={textConstants.type.heading}
        level={textConstants.level.six}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in blockquote", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum."
        type={textConstants.type.blockquote}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the content in para", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum."
        type={textConstants.type.paragraph}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the icons with text", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply"
        startIcon={getDocIcon(docsIcons.addLink)}
        endIcon={getDocIcon(docsIcons.addLink)}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the direction horizontal with text", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply"
        startIcon={getDocIcon(docsIcons.addLink)}
        endIcon={getDocIcon(docsIcons.addLink)}
        direction={textConstants.direction.horizontal}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display the direction vertical with text", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply"
        startIcon={getDocIcon(docsIcons.addLink)}
        endIcon={getDocIcon(docsIcons.addLink)}
        direction={textConstants.direction.vertical}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("should display text width adjustment to the parent area ", () => {
    let ele = renderer.create(
      <Text
        content="Lorem Ipsum is simply"
        auto={true}
        stretch={true}
      />
    );
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });


});