import React from 'react';
import { renderHook, act } from '@testing-library/react-hooks';
import { render, screen, fireEvent } from '@testing-library/react';
import useTooltip from '../Tooltip.behaviour';
import { ThemeProvider } from '@zohodesk/theme';

describe('Tooltip hook with document listerner testing', () => {
  test('element has title', () => {
    let wrapper = ({ children }) => (
      <ThemeProvider color={'blue'} mode={'dark'}>
        {children}
      </ThemeProvider>
    );
    render(<div title='title'>testing</div>);
    let { result, waitForNextUpdate } = renderHook(
      () => {
        return useTooltip({ container: document });
      },
      { wrapper }
    );

    fireEvent.mouseOver(screen.getByText(/testing/i));
    return waitForNextUpdate().then(() => {
      expect(result.current.title).toBe('title');
      expect(result.current.isHtmlTitle).toBe(false);
    });
  });
  test('element has html title', () => {
    let wrapper = ({ children }) => (
      <ThemeProvider color={'blue'} mode={'dark'}>
        {children}
      </ThemeProvider>
    );
    render(
      <div title='<b>title</b>' data-title-ishtml>
        testing
      </div>
    );
    let { result, waitForNextUpdate } = renderHook(
      () => {
        return useTooltip({ container: document });
      },
      { wrapper }
    );

    fireEvent.mouseOver(screen.getByText(/testing/i));
    return waitForNextUpdate().then(() => {
      expect(result.current.title).toBe('<b>title</b>');
      expect(result.current.isHtmlTitle).toBe(true);
    });
  });
  test('element parent has title', () => {
    let wrapper = ({ children }) => (
      <ThemeProvider color={'blue'} mode={'dark'}>
        {children}
      </ThemeProvider>
    );
    render(
      <div title='title1'>
        <span>testing</span>
      </div>
    );
    let { result, waitForNextUpdate } = renderHook(
      () => {
        return useTooltip({ container: document });
      },
      { wrapper }
    );
    console.log(wrapper, 'wrap');
    console.log(result.current, 'result');
    fireEvent.mouseOver(screen.getByText(/testing/i));
    return waitForNextUpdate().then(() => {
      expect(result.current.title).toBe('title1');
      expect(result.current.isHtmlTitle).toBe(false);
    });
  });
  test('element and parents has no title', () => {
    let wrapper = ({ children }) => (
      <ThemeProvider color={'blue'} mode={'dark'}>
        {children}
      </ThemeProvider>
    );
    render(
      <div>
        <span>testing</span>
      </div>
    );
    let { result, waitForNextUpdate } = renderHook(
      () => {
        return useTooltip({ container: document });
      },
      { wrapper }
    );

    fireEvent.mouseOver(screen.getByText(/testing/i));
    return waitForNextUpdate().catch(() => {
      expect(result.current.title).toBe(null);
    });
  });
  test('element has title to be cleared after press escape key', () => {
    let wrapper = ({ children }) => (
      <ThemeProvider color={'blue'} mode={'dark'}>
        {children}
      </ThemeProvider>
    );
    render(<div title='title'>testing</div>);
    let { result, waitForNextUpdate, waitForValueToChange } = renderHook(
      () => {
        return useTooltip({ container: document });
      },
      { wrapper }
    );

    fireEvent.mouseOver(screen.getByText(/testing/i));
    let p = waitForNextUpdate({ timeout: 10000 }).then(() => {
      console.log('test', result.current.title);
      expect(result.current.title).toBe('title');
    });
    fireEvent.keyDown(document, { code: 'Escape' });

    return p.then(() => {
      console.log('escape action');
      console.log(result.current.title);
      return waitForValueToChange(() => result.current.title === '').then(() => {
        console.log(result.current.title);
        return result.current.title === '';
      });
    });
  });
});
