import { useEffect } from "react";

const ESCAPE_CODE = "Escape";

/**
 * To used call the callback onEscape.
 * @param {*} callback - used call on Escape key press.
 * @param {*} dependencies Dependencies must be an array!
 */
export default function useEscapeEffect(callback, dependencies = []) {
    useEffect(() => {
        if (!callback) {
            return;
        }

        let onKeyDown = (event)=>{
            if (event.code === ESCAPE_CODE) {
                callback(event);
            }
        }
        
        document.addEventListener('keydown', onKeyDown);

        return () => {
            document.removeEventListener('keydown', onKeyDown);
        };

    }, dependencies);
};